aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Controller/Chapters
diff options
context:
space:
mode:
authorChristopher Young <c.t.ythegamer@gmail.com>2025-11-08 07:31:02 -0700
committerChristopher Young <c.t.ythegamer@gmail.com>2025-11-08 07:31:02 -0700
commit4cb038574515590611af081b5fe341ff4cb840b2 (patch)
tree847f90cd0fd7db9b7845d0afafdabedd3ecf3b74 /MediaBrowser.Controller/Chapters
parent438d992c8b0522f6a17f437ee991c8ef6808d749 (diff)
parent1adf441f1ca9d61c3d6c63df0ea87a870e03632f (diff)
Merge branch 'master' of https://github.com/JadedRain/jellyfin
Diffstat (limited to 'MediaBrowser.Controller/Chapters')
-rw-r--r--MediaBrowser.Controller/Chapters/IChapterManager.cs8
1 files changed, 5 insertions, 3 deletions
diff --git a/MediaBrowser.Controller/Chapters/IChapterManager.cs b/MediaBrowser.Controller/Chapters/IChapterManager.cs
index 7532e56c60..25656fd625 100644
--- a/MediaBrowser.Controller/Chapters/IChapterManager.cs
+++ b/MediaBrowser.Controller/Chapters/IChapterManager.cs
@@ -48,8 +48,10 @@ public interface IChapterManager
Task<bool> RefreshChapterImages(Video video, IDirectoryService directoryService, IReadOnlyList<ChapterInfo> chapters, bool extractImages, bool saveChapters, CancellationToken cancellationToken);
/// <summary>
/// Deletes the chapter images.
/// </summary>
- /// <param name="video">Video to use.</param>
- void DeleteChapterImages(Video video);
+ /// <param name="itemId">The item id.</param>
+ /// <param name="cancellationToken">The cancellation token.</param>
+ /// <returns>Task.</returns>
+ Task DeleteChapterDataAsync(Guid itemId, CancellationToken cancellationToken);
}
@@ -48,8 +48,10 @@ public interface IChapterManager
Task<bool> RefreshChapterImages(Video video, IDirectoryService directoryService, IReadOnlyList<ChapterInfo> chapters, bool extractImages, bool saveChapters, CancellationToken cancellationToken);
/// <summary>
- /// Deletes the chapter images.
+ /// Deletes the chapter data.
/// </summary>